@@ -131,9 +131,10 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 
 	setLayout(layout);
 
-	this->setFocus ();
-	label->setFocus ();
-	this->focusNextChild();
+//	this->setFocus ();
+//	label->setFocus ();
+//	this->focusNextChild();
+
 }
 
 LoginDialog::~LoginDialog()
@@ -142,16 +143,6 @@ LoginDialog::~LoginDialog()
 void LoginDialog::about()
 {
     QMessageBox::about(this, "About qtWallet", TEXT_ABOUT);
-//    if (aboutDialogDlg.isNull()) {
-//		aboutDialogDlg = new AboutDialog(this);
-//		aboutDialogDlg->showMaximized();
-//#ifdef Q_WS_MAEMO_5
-//		aboutDialogDlg->setAttribute(Qt::WA_Maemo5StackedWindow);
-//#endif
-//		aboutDialogDlg->setAttribute(Qt::WA_DeleteOnClose);
-//        //connect(detailWindowEdit, SIGNAL(destroyed(QObject*)), this, SLOT(windowDestroyed(QObject*)));
-//        aboutDialogDlg->show();
-//	}
 }
 void LoginDialog::clearS()
 {
@@ -221,45 +212,13 @@ void LoginDialog::select(const QString& a) {
 }
 
 void LoginDialog::keyPressEvent(QKeyEvent* event) {
-//	//qDebug()<<"key pressed " << event->key();
-//
-//	if (event->key() >= Qt::Key_0 && event->key() <= Qt::Key_9) {
-//		if (current.size() < KEY_SIZE) {
-//			current += (char)(event->key());
-//			label->setText (current); //QString ("************************").right(current.size()));
-//		}
-//		event->accept();
-//	}
-//	else {
-//		if (event->key() == Qt::Key_Backspace || event->key() == Qt::Key_Delete) {
-//			if (current.size () > 0) {
-//				current = current.left (current.size ()-1);
-//				label->setText (current); //QString ("************************").right(current.size()));
-//			}
-//			event->accept();
-//		}
-//		else {
 	if (event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter) {
-				event->accept();
-				acceptS();
-			}
-			else {
-				QCoreApplication::sendEvent (label, event);
-			}
-	//				event->accept();//QWidget::keyPressEvent(event);
-//QLineEdit::keyPressEvent(event);
-//			}
-//		}
-//	}
+		event->accept();
+		acceptS();
+	}
 }
 
 void LoginDialog::resetF () {
 	isFirstTime = true;
 	NTimes = 0;
 }
-/*
-void LoginDialog::focusOutEvent ( QFocusEvent * event ) {
-	
-	qDebug () << "LOST FOCUS";
-}
-*/
