@@ -21,7 +21,7 @@ public:
 	~LoginDialog();
 
 	void resetF ();
-	//void keyPressEvent(QKeyEvent* event);
+	void keyPressEvent(QKeyEvent* event);
 
 private slots:
 	void select(const QString& a);
@@ -33,8 +33,8 @@ private:
 	QPointer<AboutDialog> aboutDialogDlg;
 	QPointer <QMessageBox> messageBox;
 	//void focusOutEvent ( QFocusEvent * event );
-	QString current;
-	QString repeat;
+	//QString current;
+	//QString repeat;
 	eWallet * parent;
 	
 	int NTimes;
