@@ -77,7 +77,7 @@ void eWallet::showList () {
 
 		fnListWidget = new QListWidget(this);
 		fnListWidget->setSortingEnabled(false);
-		//fnListWidget->setSortingEnabled(false);
+		fnListWidget->setFocusPolicy(Qt::NoFocus);
 		vboxlayout->addWidget(fnListWidget);
 
 		QObject::connect(fnListWidget, SIGNAL(itemClicked(QListWidgetItem *)), this, SLOT(selectItem(QListWidgetItem *)));
@@ -333,7 +333,7 @@ void eWallet::loadTypesAndFields () {
 }
 
 void eWallet::keyPressEvent(QKeyEvent* event) {
-	//qDebug()<<"key pressed " << event->key();
+	qDebug()<<"key pressed " << event->key();
 	
 	if (!isAskPassword) {
 		if (searchField->isHidden()) {
@@ -343,9 +343,18 @@ void eWallet::keyPressEvent(QKeyEvent* event) {
 			searchField->setFocus();
 
 			QCoreApplication::sendEvent (searchField, event);
-
 			event->accept();
 		}
+		else {
+//			if (event->key () == Qt::Key_Up) {
+//				cancelSearch->hide ();
+//				searchField->hide ();
+//				hideSearch->hide ();
+//				event->accept();
+//			}
+//			else
+				QWidget::keyPressEvent(event);//event->accept();
+		}
 	}
 	else {
 		QWidget::keyPressEvent(event);//event->accept();
